LoggerCore class

설명

개발 편의를 위해 로깅이 필요할 때 LoggerCore의 함수들을 이용한다.

로그 형식

기본 로그 형식은 아래와 같으며, 함수 이름, 파일 이름, 예외, 호출스택은 존재할때만 표시된다.

[ logLevel ] time [ category ] from 'functionName' of 'fileName'
<Title>
Content
Exception: exception

----- Start of Stack Trace -----
#0    function
#1    main
----- End of Stack Trace -----

Constructors

LoggerCore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

categoryFilter LogCategory?
해당 값이 null이 아니면 특정 카테고리의 로그만 출력한다.
getter/setter pair

Static Methods

log({required LogLevel logLevel, String? content, String? title, LogCategory? category, Object? exception, StackTrace? stackTrace, int maxStackTraceLine = 20, bool hideStackTrace = false}) → void
터미널에 content에 해당하는 로그를 출력한다. Release 빌드일 때는 Sentry 측에 예외와 호출스택 정보만 전달하고, 터미널 출력부는 실행되지 않는다.