LogLevel enum
로그 수준에 대한 열거형으로, 로그 수준에 맞는 색상, 텍스트 효과 등을 가져올 수 있다.
Values
Properties
- brightColor → LogColorCode
-
no setter
- color → LogColorCode
-
no setter
- effect → LogEffectCode?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- string → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited